@@ -167,40 +167,40 @@ fn test_lines() {
     dom_updater.patch_dom(
         &simple_program,
         vec![
-            Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 0, 0, 0]),
-                &leaf::text("0"),
-                &leaf::text("1"),
+            Patch::replace_node(
+                None,
+                TreePath::new(vec![1, 0, 0, 0, 0, 0]),
+                &text("1"),
             ),
-            Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 1, 0, 0]),
-                &leaf::text("1"),
-                &leaf::text("2"),
+            Patch::replace_node(
+                None,
+                TreePath::new(vec![1, 0, 0, 1, 0, 0]),
+                &text("2"),
             ),
-            Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 2, 0, 0]),
-                &leaf::text("2"),
-                &leaf::text("3"),
+            Patch::replace_node(
+                None,
+                TreePath::new(vec![1, 0, 0, 2, 0, 0]),
+                &text("3"),
             ),
-            Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 3, 0, 0]),
-                &leaf::text("3"),
-                &leaf::text("4"),
+            Patch::replace_node(
+                None,
+                TreePath::new(vec![1, 0, 0, 3, 0, 0]),
+                &text("4"),
             ),
-            Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 0, 4, 0, 0]),
-                &leaf::text("4"),
-                &leaf::text("5"),
+            Patch::replace_node(
+                None,
+                TreePath::new(vec![1, 0, 0, 4, 0, 0]),
+                &text("5"),
             ),
             Patch::insert_node(
                 Some(&"div"),
-                TreePath::new(vec![0, 1, 0, 0, 0]),
+                TreePath::new(vec![1, 0, 0, 0]),
                 &inserted,
             ),
-            Patch::replace_leaf(
-                TreePath::new(vec![0, 1, 0, 1, 0]),
-                &leaf::text("line: 0, column: 0"),
-                &leaf::text("line: 1, column: 0"),
+            Patch::replace_node(
+                None,
+                TreePath::new(vec![1, 0, 1, 0]),
+                &text("line: 1, column: 0"),
             ),
         ],
     );
