@@ -114,51 +114,49 @@ fn test1() {
                 TreePath::new(vec![1, 0, 0, 1, 0, 0,]),
                 &text("0")
             ),
+            Patch::remove_node(Some(&"div"), TreePath::new(vec![1, 0, 0, 0,]),),
             Patch::replace_node(
                 None,
                 TreePath::new(vec![1, 0, 0, 2, 0, 0,]),
                 &text("3")
             ),
-            Patch::insert_node(
+            Patch::insert_before_node(
                 Some(&"div"),
                 TreePath::new(vec![1, 0, 0, 2,]),
-                &div(
-                    vec![
-                        class("grid__number__line"),
-                        key("623356695095054844")
-                    ],
-                    vec![
-                        div(vec![class("grid__number")], vec![text(1)]),
-                        div(
-                            vec![class("grid__line")],
-                            vec![
-                                div(vec![], vec![text("C")]),
-                                div(vec![], vec![text("J")]),
-                                div(vec![], vec![text("K")]),
-                                div(vec![], vec![text("\n")]),
-                            ]
-                        ),
-                    ]
-                ),
+                vec![
+                    &div(
+                        vec![
+                            class("grid__number__line"),
+                            key("623356695095054844")
+                        ],
+                        vec![
+                            div(vec![class("grid__number")], vec![text(1)]),
+                            div(
+                                vec![class("grid__line")],
+                                vec![
+                                    div(vec![], vec![text("C")]),
+                                    div(vec![], vec![text("J")]),
+                                    div(vec![], vec![text("K")]),
+                                    div(vec![], vec![text("\n")]),
+                                ]
+                            ),
+                        ]
+                    ),
+                    &div(
+                        vec![
+                            class("grid__number__line"),
+                            key("4638962052468762037")
+                        ],
+                        vec![
+                            div(vec![class("grid__number")], vec![text(2)]),
+                            div(
+                                vec![class("grid__line")],
+                                vec![div(vec![], vec![text("\n")]),]
+                            ),
+                        ]
+                    )
+                ]
             ),
-            Patch::insert_node(
-                Some(&"div"),
-                TreePath::new(vec![1, 0, 0, 2,]),
-                &div(
-                    vec![
-                        class("grid__number__line"),
-                        key("4638962052468762037")
-                    ],
-                    vec![
-                        div(vec![class("grid__number")], vec![text(2)]),
-                        div(
-                            vec![class("grid__line")],
-                            vec![div(vec![], vec![text("\n")]),]
-                        ),
-                    ]
-                )
-            ),
-            Patch::remove_node(Some(&"div"), TreePath::new(vec![1, 0, 0, 0,]),),
             Patch::replace_node(
                 None,
                 TreePath::new(vec![1, 0, 1, 0,]),
